# lab3_group_analysis.R
# Analysis of Group Hue Naming Data
# Lew Harvey
# 14 June 2010

# load the nlme library to use lme()
library(nlme)

# read in group data in wide format from Excel text file
fn <- file("lab3_group_data_wide.txt")
df.wide <- read.delim(fn, header=TRUE)

# ******************************************************
# reshape the file into long format
# Note: reshape() is a bit of a pain to use but what it does
# is take data that are in a so-called wide format
# (one row per subject, separate columns per dependent variable)
# and put it into the long formate needed by many R analysis routines
# (multiple rows per subject, single column per dependent variable)
df.long <- reshape(df.wide,
	varying = list(c("zeroB", "zeroG", "zeroY"), c("pureB", "pureG", "pureY")),
	idvar = "subj",
	times = c("blue", "green", "yellow"),
	v.names = c("zero_wavelength", "pure_wavelength"),
	timevar = "color",
	direction = "long")
rownames(df.long) <- 1:dim(df.long)[1]
df.long$color <- factor(df.long$color)
# ******************************************************

# use shorter name for the data frame
df <- df.long

# ------------------------------------------------------
# Make Figure 1
# ------------------------------------------------------
plot1 <- function() {
	par(mfcol = c(1,2))
	# Make a strip chart of the zero-crossing data
	stripchart(zero_wavelength ~ color, data = df, method = "jitter", jitter = 0.03,
		ylab = "zero-crossing wavelength (nm)", 
		xlab = "Color", ylim = c(400, 650), vertical = TRUE)

	# Make a box plot of the zero-crossing data:
	boxplot(zero_wavelength ~ color, data = df, ylim = c(400, 650),
		ylab = "zero-crossing wavelength (nm)", 
		xlab = "Color", ylim = c(400, 650))
	par(mfcol = c(1,1))
}

# ------------------------------------------------------
# Make Figure 2
# ------------------------------------------------------
plot2 <- function() {
	par(mfcol = c(1,2))
	# Make a strip chart of the pure-color data
	stripchart(pure_wavelength ~ color, data = df, method = "jitter", jitter = 0.03,
		ylab = "pure color wavelength (nm)", 
		xlab = "Color", ylim = c(400, 650), vertical = TRUE)

	# Make a box plot of the pure-color data:
	boxplot(pure_wavelength ~ color, data = df, ylim = c(400, 650),
		ylab = "pure color wavelength (nm)", 
		xlab = "Color", ylim = c(400, 650))
		par(mfcol = c(1,1))
}

# ------------------------------------------------------
# Make Figure 3
# plot the wavelengths for the pure colors from settings
# against the wavelengths derived from zero crossings
# ------------------------------------------------------
plot3 <- function() {
	par(mfcol = c(1,1))
	par(pty = "s") # make graph square
	plot(pure_wavelength ~ zero_wavelength, data = df, type="n",
		xlim = c(400, 650),
		ylim = c(400, 650),
		xlab = "zero-crossing wavelengths",
		ylab = "pure-color wavelength",
		main = "Fig 3: Hue-Naming Laboratory Group Data")
	abline(0,1)
	points(pure_wavelength ~ zero_wavelength, data=subset(df,df$color=="blue"), col="blue", pch=19)
	points(pure_wavelength ~ zero_wavelength, data=subset(df,df$color=="green"), col="green", pch=19)
	points(pure_wavelength ~ zero_wavelength, data=subset(df,df$color=="yellow"), col="orange", pch=19)
	par(pty = "m") # restore normal graph aspect ratio
}

# Testing the hypothesis that color is independent of wavelength and gender
# Compute the mixed-effects (within and between factors ANOVA
a <- lme(pure_wavelength ~ color * gender *section, random = ~ 1 | subj, data = df)

# print a summary of the analysis of variance
print(anova(a))

# Print a table of means for the three colors
print("color means")
print(tapply(df$pure_wavelength, df$color, mean, na.rm=TRUE))
print(tapply(df$zero_wavelength, df$color, mean, na.rm=TRUE))

# Print a table of means for the genders
print("gender means")
print(tapply(df$pure_wavelength, df$gender, mean, na.rm=TRUE))
print(tapply(df$zero_wavelength, df$gender, mean, na.rm=TRUE))

# Print a table of means for gender and colors
print("gender and color means")
print(tapply(df$pure_wavelength, INDEX=list(df$gender, df$color), mean, na.rm=TRUE))
print(tapply(df$zero_wavelength, INDEX=list(df$gender, df$color), mean, na.rm=TRUE))

# Print correlation between the two ways of measuring hue
print("correlation between pure color wavelengths and zero-crossing wavelengths")
print(cor(df$pure_wavelength, df$zero_wavelength))
